// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

#include "manual.h"
#include <stdio.h>

#define PRINT_CONSTANT(CONSTANT_NAME) \
    printf("%s;", #CONSTANT_NAME); \
    printf(_Generic((CONSTANT_NAME), \
                    char *: "%s", \
                    const char *: "%s", \
                    char: "%c", \
                    signed char: "%hhd", \
                    unsigned char: "%hhu", \
                    short int: "%hd", \
                    unsigned short int: "%hu", \
                    int: "%d", \
                    unsigned int: "%u", \
                    long: "%ld", \
                    unsigned long: "%lu", \
                    long long: "%lld", \
                    unsigned long long: "%llu", \
                    float: "%f", \
                    double: "%f", \
                    long double: "%ld"), \
           CONSTANT_NAME); \
    printf("\n");

int main() {
    PRINT_CONSTANT((guint) GTK_ACCEL_LOCKED);
    PRINT_CONSTANT((guint) GTK_ACCEL_MASK);
    PRINT_CONSTANT((guint) GTK_ACCEL_VISIBLE);
    PRINT_CONSTANT((gint) GTK_ALIGN_BASELINE);
    PRINT_CONSTANT((gint) GTK_ALIGN_CENTER);
    PRINT_CONSTANT((gint) GTK_ALIGN_END);
    PRINT_CONSTANT((gint) GTK_ALIGN_FILL);
    PRINT_CONSTANT((gint) GTK_ALIGN_START);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_IDLE);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_LOGOUT);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_SUSPEND);
    PRINT_CONSTANT((guint) GTK_APPLICATION_INHIBIT_SWITCH);
    PRINT_CONSTANT((gint) GTK_ARROWS_BOTH);
    PRINT_CONSTANT((gint) GTK_ARROWS_END);
    PRINT_CONSTANT((gint) GTK_ARROWS_START);
    PRINT_CONSTANT((gint) GTK_ARROW_DOWN);
    PRINT_CONSTANT((gint) GTK_ARROW_LEFT);
    PRINT_CONSTANT((gint) GTK_ARROW_NONE);
    PRINT_CONSTANT((gint) GTK_ARROW_RIGHT);
    PRINT_CONSTANT((gint) GTK_ARROW_UP);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CONFIRM);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CONTENT);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_CUSTOM);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_INTRO);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_PROGRESS);
    PRINT_CONSTANT((gint) GTK_ASSISTANT_PAGE_SUMMARY);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_BOTTOM);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_CENTER);
    PRINT_CONSTANT((gint) GTK_BASELINE_POSITION_TOP);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DASHED);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DOTTED);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_DOUBLE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_GROOVE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_HIDDEN);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_INSET);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_NONE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_OUTSET);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_RIDGE);
    PRINT_CONSTANT((gint) GTK_BORDER_STYLE_SOLID);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_DUPLICATE_ID);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_ID);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_PROPERTY);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_SIGNAL);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_TAG);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_TYPE_FUNCTION);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_INVALID_VALUE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_MISSING_ATTRIBUTE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_MISSING_PROPERTY_VALUE);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_OBJECT_TYPE_REFUSED);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_TEMPLATE_MISMATCH);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_UNHANDLED_TAG);
    PRINT_CONSTANT((gint) GTK_BUILDER_ERROR_VERSION_MISMATCH);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_CENTER);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_EDGE);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_END);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_EXPAND);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_SPREAD);
    PRINT_CONSTANT((gint) GTK_BUTTONBOX_START);
    PRINT_CONSTANT((gint) GTK_BUTTONS_CANCEL);
    PRINT_CONSTANT((gint) GTK_BUTTONS_CLOSE);
    PRINT_CONSTANT((gint) GTK_BUTTONS_NONE);
    PRINT_CONSTANT((gint) GTK_BUTTONS_OK);
    PRINT_CONSTANT((gint) GTK_BUTTONS_OK_CANCEL);
    PRINT_CONSTANT((gint) GTK_BUTTONS_YES_NO);
    PRINT_CONSTANT((gint) GTK_BUTTON_ROLE_CHECK);
    PRINT_CONSTANT((gint) GTK_BUTTON_ROLE_NORMAL);
    PRINT_CONSTANT((gint) GTK_BUTTON_ROLE_RADIO);
    PRINT_CONSTANT((guint) GTK_CALENDAR_NO_MONTH_CHANGE);
    PRINT_CONSTANT((guint) GTK_CALENDAR_SHOW_DAY_NAMES);
    PRINT_CONSTANT((guint) GTK_CALENDAR_SHOW_DETAILS);
    PRINT_CONSTANT((guint) GTK_CALENDAR_SHOW_HEADING);
    PRINT_CONSTANT((guint) GTK_CALENDAR_SHOW_WEEK_NUMBERS);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_ACCEL_MODE_GTK);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_ACCEL_MODE_OTHER);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_EXPANDABLE);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_EXPANDED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_FOCUSED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_INSENSITIVE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_ACTIVATABLE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_EDITABLE);
    PRINT_CONSTANT((gint) GTK_CELL_RENDERER_MODE_INERT);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_PRELIT);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_SELECTED);
    PRINT_CONSTANT((guint) GTK_CELL_RENDERER_SORTED);
    PRINT_CONSTANT((gint) GTK_CORNER_BOTTOM_LEFT);
    PRINT_CONSTANT((gint) GTK_CORNER_BOTTOM_RIGHT);
    PRINT_CONSTANT((gint) GTK_CORNER_TOP_LEFT);
    PRINT_CONSTANT((gint) GTK_CORNER_TOP_RIGHT);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_DEPRECATED);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_FAILED);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_IMPORT);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_NAME);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_SYNTAX);
    PRINT_CONSTANT((gint) GTK_CSS_PROVIDER_ERROR_UNKNOWN_VALUE);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_BINDING_SET);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_COLOR_DEFINITION);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_DECLARATION);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_DOCUMENT);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_IMPORT);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_KEYFRAMES);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_RULESET);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_SELECTOR);
    PRINT_CONSTANT((gint) GTK_CSS_SECTION_VALUE);
    PRINT_CONSTANT((guint) GTK_DEBUG_ACTIONS);
    PRINT_CONSTANT((guint) GTK_DEBUG_BASELINES);
    PRINT_CONSTANT((guint) GTK_DEBUG_BUILDER);
    PRINT_CONSTANT((guint) GTK_DEBUG_GEOMETRY);
    PRINT_CONSTANT((guint) GTK_DEBUG_ICONTHEME);
    PRINT_CONSTANT((guint) GTK_DEBUG_INTERACTIVE);
    PRINT_CONSTANT((guint) GTK_DEBUG_KEYBINDINGS);
    PRINT_CONSTANT((guint) GTK_DEBUG_LAYOUT);
    PRINT_CONSTANT((guint) GTK_DEBUG_MISC);
    PRINT_CONSTANT((guint) GTK_DEBUG_MODULES);
    PRINT_CONSTANT((guint) GTK_DEBUG_MULTIHEAD);
    PRINT_CONSTANT((guint) GTK_DEBUG_NO_CSS_CACHE);
    PRINT_CONSTANT((guint) GTK_DEBUG_NO_PIXEL_CACHE);
    PRINT_CONSTANT((guint) GTK_DEBUG_PIXEL_CACHE);
    PRINT_CONSTANT((guint) GTK_DEBUG_PLUGSOCKET);
    PRINT_CONSTANT((guint) GTK_DEBUG_PRINTING);
    PRINT_CONSTANT((guint) GTK_DEBUG_RESIZE);
    PRINT_CONSTANT((guint) GTK_DEBUG_SIZE_REQUEST);
    PRINT_CONSTANT((guint) GTK_DEBUG_TEXT);
    PRINT_CONSTANT((guint) GTK_DEBUG_TOUCHSCREEN);
    PRINT_CONSTANT((guint) GTK_DEBUG_TREE);
    PRINT_CONSTANT((guint) GTK_DEBUG_UPDATES);
    PRINT_CONSTANT((gint) GTK_DELETE_CHARS);
    PRINT_CONSTANT((gint) GTK_DELETE_DISPLAY_LINES);
    PRINT_CONSTANT((gint) GTK_DELETE_DISPLAY_LINE_ENDS);
    PRINT_CONSTANT((gint) GTK_DELETE_PARAGRAPHS);
    PRINT_CONSTANT((gint) GTK_DELETE_PARAGRAPH_ENDS);
    PRINT_CONSTANT((gint) GTK_DELETE_WHITESPACE);
    PRINT_CONSTANT((gint) GTK_DELETE_WORDS);
    PRINT_CONSTANT((gint) GTK_DELETE_WORD_ENDS);
    PRINT_CONSTANT((guint) GTK_DEST_DEFAULT_ALL);
    PRINT_CONSTANT((guint) GTK_DEST_DEFAULT_DROP);
    PRINT_CONSTANT((guint) GTK_DEST_DEFAULT_HIGHLIGHT);
    PRINT_CONSTANT((guint) GTK_DEST_DEFAULT_MOTION);
    PRINT_CONSTANT((guint) GTK_DIALOG_DESTROY_WITH_PARENT);
    PRINT_CONSTANT((guint) GTK_DIALOG_MODAL);
    PRINT_CONSTANT((guint) GTK_DIALOG_USE_HEADER_BAR);
    PRINT_CONSTANT((gint) GTK_DIR_DOWN);
    PRINT_CONSTANT((gint) GTK_DIR_LEFT);
    PRINT_CONSTANT((gint) GTK_DIR_RIGHT);
    PRINT_CONSTANT((gint) GTK_DIR_TAB_BACKWARD);
    PRINT_CONSTANT((gint) GTK_DIR_TAB_FORWARD);
    PRINT_CONSTANT((gint) GTK_DIR_UP);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_ERROR);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_GRAB_BROKEN);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_NO_TARGET);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_SUCCESS);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_TIMEOUT_EXPIRED);
    PRINT_CONSTANT((gint) GTK_DRAG_RESULT_USER_CANCELLED);
    PRINT_CONSTANT((gint) GTK_ENTRY_ICON_PRIMARY);
    PRINT_CONSTANT((gint) GTK_ENTRY_ICON_SECONDARY);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_BOTH_AXES);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_DISCRETE);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_HORIZONTAL);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_KINETIC);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_NONE);
    PRINT_CONSTANT((guint) GTK_EVENT_CONTROLLER_SCROLL_VERTICAL);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_CLAIMED);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_DENIED);
    PRINT_CONSTANT((gint) GTK_EVENT_SEQUENCE_NONE);
    PRINT_CONSTANT((guint) GTK_EXPAND);
    PRINT_CONSTANT((gint) GTK_EXPANDER_COLLAPSED);
    PRINT_CONSTANT((gint) GTK_EXPANDER_EXPANDED);
    PRINT_CONSTANT((gint) GTK_EXPANDER_SEMI_COLLAPSED);
    PRINT_CONSTANT((gint) GTK_EXPANDER_SEMI_EXPANDED);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_OPEN);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_SAVE);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_CONFIRMATION_CONFIRM);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_CONFIRMATION_SELECT_AGAIN);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_ALREADY_EXISTS);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_BAD_FILENAME);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_INCOMPLETE_HOSTNAME);
    PRINT_CONSTANT((gint) GTK_FILE_CHOOSER_ERROR_NONEXISTENT);
    PRINT_CONSTANT((guint) GTK_FILE_FILTER_DISPLAY_NAME);
    PRINT_CONSTANT((guint) GTK_FILE_FILTER_FILENAME);
    PRINT_CONSTANT((guint) GTK_FILE_FILTER_MIME_TYPE);
    PRINT_CONSTANT((guint) GTK_FILE_FILTER_URI);
    PRINT_CONSTANT((guint) GTK_FILL);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_FAMILY);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_FEATURES);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_SIZE);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_STYLE);
    PRINT_CONSTANT((guint) GTK_FONT_CHOOSER_LEVEL_VARIATIONS);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_DIR_LTR);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_DIR_RTL);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_REGULAR);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_SIZE);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_SVG);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_FORCE_SYMBOLIC);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_GENERIC_FALLBACK);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_NO_SVG);
    PRINT_CONSTANT((guint) GTK_ICON_LOOKUP_USE_BUILTIN);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_BUTTON);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_DIALOG);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_DND);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_INVALID);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_LARGE_TOOLBAR);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_MENU);
    PRINT_CONSTANT((gint) GTK_ICON_SIZE_SMALL_TOOLBAR);
    PRINT_CONSTANT((gint) GTK_ICON_THEME_FAILED);
    PRINT_CONSTANT((gint) GTK_ICON_THEME_NOT_FOUND);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_ABOVE);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_BELOW);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_INTO);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_LEFT);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_DROP_RIGHT);
    PRINT_CONSTANT((gint) GTK_ICON_VIEW_NO_DROP);
    PRINT_CONSTANT((gint) GTK_IMAGE_ANIMATION);
    PRINT_CONSTANT((gint) GTK_IMAGE_EMPTY);
    PRINT_CONSTANT((gint) GTK_IMAGE_GICON);
    PRINT_CONSTANT((gint) GTK_IMAGE_ICON_NAME);
    PRINT_CONSTANT((gint) GTK_IMAGE_ICON_SET);
    PRINT_CONSTANT((gint) GTK_IMAGE_PIXBUF);
    PRINT_CONSTANT((gint) GTK_IMAGE_STOCK);
    PRINT_CONSTANT((gint) GTK_IMAGE_SURFACE);
    PRINT_CONSTANT((gint) GTK_IM_PREEDIT_CALLBACK);
    PRINT_CONSTANT((gint) GTK_IM_PREEDIT_NONE);
    PRINT_CONSTANT((gint) GTK_IM_PREEDIT_NOTHING);
    PRINT_CONSTANT((gint) GTK_IM_STATUS_CALLBACK);
    PRINT_CONSTANT((gint) GTK_IM_STATUS_NONE);
    PRINT_CONSTANT((gint) GTK_IM_STATUS_NOTHING);
    PRINT_CONSTANT(GTK_INPUT_ERROR);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_EMOJI);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_INHIBIT_OSK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_LOWERCASE);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NONE);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NO_EMOJI);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_NO_SPELLCHECK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_SPELLCHECK);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_CHARS);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_SENTENCES);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_UPPERCASE_WORDS);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_VERTICAL_WRITING);
    PRINT_CONSTANT((guint) GTK_INPUT_HINT_WORD_COMPLETION);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_ALPHA);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_DIGITS);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_EMAIL);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_FREE_FORM);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_NAME);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_NUMBER);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PASSWORD);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PHONE);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_PIN);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_TERMINAL);
    PRINT_CONSTANT((gint) GTK_INPUT_PURPOSE_URL);
    PRINT_CONSTANT((guint) GTK_JUNCTION_BOTTOM);
    PRINT_CONSTANT((guint) GTK_JUNCTION_CORNER_BOTTOMLEFT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_CORNER_BOTTOMRIGHT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_CORNER_TOPLEFT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_CORNER_TOPRIGHT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_LEFT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_NONE);
    PRINT_CONSTANT((guint) GTK_JUNCTION_RIGHT);
    PRINT_CONSTANT((guint) GTK_JUNCTION_TOP);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_CENTER);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_FILL);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_LEFT);
    PRINT_CONSTANT((gint) GTK_JUSTIFY_RIGHT);
    PRINT_CONSTANT((gint) GTK_LEVEL_BAR_MODE_CONTINUOUS);
    PRINT_CONSTANT((gint) GTK_LEVEL_BAR_MODE_DISCRETE);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_FULL);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_HIGH);
    PRINT_CONSTANT(GTK_LEVEL_BAR_OFFSET_LOW);
    PRINT_CONSTANT((gint) GTK_LICENSE_AGPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_AGPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_APACHE_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_ARTISTIC);
    PRINT_CONSTANT((gint) GTK_LICENSE_BSD);
    PRINT_CONSTANT((gint) GTK_LICENSE_BSD_3);
    PRINT_CONSTANT((gint) GTK_LICENSE_CUSTOM);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_2_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_GPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_2_1);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_2_1_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_3_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_LGPL_3_0_ONLY);
    PRINT_CONSTANT((gint) GTK_LICENSE_MIT_X11);
    PRINT_CONSTANT((gint) GTK_LICENSE_MPL_2_0);
    PRINT_CONSTANT((gint) GTK_LICENSE_UNKNOWN);
    PRINT_CONSTANT(GTK_MAX_COMPOSE_LEN);
    PRINT_CONSTANT((gint) GTK_MENU_DIR_CHILD);
    PRINT_CONSTANT((gint) GTK_MENU_DIR_NEXT);
    PRINT_CONSTANT((gint) GTK_MENU_DIR_PARENT);
    PRINT_CONSTANT((gint) GTK_MENU_DIR_PREV);
    PRINT_CONSTANT((gint) GTK_MESSAGE_ERROR);
    PRINT_CONSTANT((gint) GTK_MESSAGE_INFO);
    PRINT_CONSTANT((gint) GTK_MESSAGE_OTHER);
    PRINT_CONSTANT((gint) GTK_MESSAGE_QUESTION);
    PRINT_CONSTANT((gint) GTK_MESSAGE_WARNING);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_BUFFER_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_DISPLAY_LINES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_DISPLAY_LINE_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_HORIZONTAL_PAGES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_LOGICAL_POSITIONS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PAGES);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PARAGRAPHS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_PARAGRAPH_ENDS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_VISUAL_POSITIONS);
    PRINT_CONSTANT((gint) GTK_MOVEMENT_WORDS);
    PRINT_CONSTANT((gint) GTK_NOTEBOOK_TAB_FIRST);
    PRINT_CONSTANT((gint) GTK_NOTEBOOK_TAB_LAST);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_LEFT_TO_RIGHT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_BOTTOM_TO_TOP_RIGHT_TO_LEFT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_BOTTOM_TO_TOP);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_LEFT_TO_RIGHT_TOP_TO_BOTTOM);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_BOTTOM_TO_TOP);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_RIGHT_TO_LEFT_TOP_TO_BOTTOM);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_LEFT_TO_RIGHT);
    PRINT_CONSTANT((gint) GTK_NUMBER_UP_LAYOUT_TOP_TO_BOTTOM_RIGHT_TO_LEFT);
    PRINT_CONSTANT((gint) GTK_ORIENTATION_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_ORIENTATION_VERTICAL);
    PRINT_CONSTANT((gint) GTK_PACK_DIRECTION_BTT);
    PRINT_CONSTANT((gint) GTK_PACK_DIRECTION_LTR);
    PRINT_CONSTANT((gint) GTK_PACK_DIRECTION_RTL);
    PRINT_CONSTANT((gint) GTK_PACK_DIRECTION_TTB);
    PRINT_CONSTANT((gint) GTK_PACK_END);
    PRINT_CONSTANT((gint) GTK_PACK_START);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_BUTTON);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_RING);
    PRINT_CONSTANT((gint) GTK_PAD_ACTION_STRIP);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_LANDSCAPE);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_PORTRAIT);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_REVERSE_LANDSCAPE);
    PRINT_CONSTANT((gint) GTK_PAGE_ORIENTATION_REVERSE_PORTRAIT);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_ALL);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_EVEN);
    PRINT_CONSTANT((gint) GTK_PAGE_SET_ODD);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_DOWN);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_LEFT);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_RIGHT);
    PRINT_CONSTANT((gint) GTK_PAN_DIRECTION_UP);
    PRINT_CONSTANT(GTK_PAPER_NAME_A3);
    PRINT_CONSTANT(GTK_PAPER_NAME_A4);
    PRINT_CONSTANT(GTK_PAPER_NAME_A5);
    PRINT_CONSTANT(GTK_PAPER_NAME_B5);
    PRINT_CONSTANT(GTK_PAPER_NAME_EXECUTIVE);
    PRINT_CONSTANT(GTK_PAPER_NAME_LEGAL);
    PRINT_CONSTANT(GTK_PAPER_NAME_LETTER);
    PRINT_CONSTANT((gint) GTK_PATH_CLASS);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_APPLICATION);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_GTK);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_HIGHEST);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_LOWEST);
    PRINT_CONSTANT(GTK_PATH_PRIO_MASK);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_RC);
    PRINT_CONSTANT((gint) GTK_PATH_PRIO_THEME);
    PRINT_CONSTANT((gint) GTK_PATH_WIDGET);
    PRINT_CONSTANT((gint) GTK_PATH_WIDGET_CLASS);
    PRINT_CONSTANT((gint) GTK_PHASE_BUBBLE);
    PRINT_CONSTANT((gint) GTK_PHASE_CAPTURE);
    PRINT_CONSTANT((gint) GTK_PHASE_NONE);
    PRINT_CONSTANT((gint) GTK_PHASE_TARGET);
    PRINT_CONSTANT((guint) GTK_PLACES_OPEN_NEW_TAB);
    PRINT_CONSTANT((guint) GTK_PLACES_OPEN_NEW_WINDOW);
    PRINT_CONSTANT((guint) GTK_PLACES_OPEN_NORMAL);
    PRINT_CONSTANT((gint) GTK_POLICY_ALWAYS);
    PRINT_CONSTANT((gint) GTK_POLICY_AUTOMATIC);
    PRINT_CONSTANT((gint) GTK_POLICY_EXTERNAL);
    PRINT_CONSTANT((gint) GTK_POLICY_NEVER);
    PRINT_CONSTANT((gint) GTK_POPOVER_CONSTRAINT_NONE);
    PRINT_CONSTANT((gint) GTK_POPOVER_CONSTRAINT_WINDOW);
    PRINT_CONSTANT((gint) GTK_POS_BOTTOM);
    PRINT_CONSTANT((gint) GTK_POS_LEFT);
    PRINT_CONSTANT((gint) GTK_POS_RIGHT);
    PRINT_CONSTANT((gint) GTK_POS_TOP);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_SIMPLEX);
    PRINT_CONSTANT((gint) GTK_PRINT_DUPLEX_VERTICAL);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_GENERAL);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_INTERNAL_ERROR);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_INVALID_FILE);
    PRINT_CONSTANT((gint) GTK_PRINT_ERROR_NOMEM);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_EXPORT);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PREVIEW);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PRINT);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_APPLY);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_CANCEL);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_ERROR);
    PRINT_CONSTANT((gint) GTK_PRINT_OPERATION_RESULT_IN_PROGRESS);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_ALL);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_CURRENT);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_RANGES);
    PRINT_CONSTANT((gint) GTK_PRINT_PAGES_SELECTION);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_DRAFT);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_HIGH);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_LOW);
    PRINT_CONSTANT((gint) GTK_PRINT_QUALITY_NORMAL);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_COLLATE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DEFAULT_SOURCE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DITHER);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_DUPLEX);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_FINISHINGS);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_MEDIA_TYPE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_NUMBER_UP);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_NUMBER_UP_LAYOUT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_N_COPIES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_ORIENTATION);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_BASENAME);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_BIN);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_DIR);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_FILE_FORMAT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_OUTPUT_URI);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAGE_RANGES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAGE_SET);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_FORMAT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_HEIGHT);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PAPER_WIDTH);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINTER);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINTER_LPI);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_PRINT_PAGES);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_QUALITY);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION_X);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_RESOLUTION_Y);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_REVERSE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_SCALE);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_USE_COLOR);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_WIN32_DRIVER_EXTRA);
    PRINT_CONSTANT(GTK_PRINT_SETTINGS_WIN32_DRIVER_VERSION);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_FINISHED);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_FINISHED_ABORTED);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_GENERATING_DATA);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_INITIAL);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PENDING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PENDING_ISSUE);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PREPARING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_PRINTING);
    PRINT_CONSTANT((gint) GTK_PRINT_STATUS_SENDING_DATA);
    PRINT_CONSTANT(GTK_PRIORITY_RESIZE);
    PRINT_CONSTANT((guint) GTK_RC_BASE);
    PRINT_CONSTANT((guint) GTK_RC_BG);
    PRINT_CONSTANT((guint) GTK_RC_FG);
    PRINT_CONSTANT((guint) GTK_RC_TEXT);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_ACTIVE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_APPLICATION);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_BASE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_BG);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_BG_PIXMAP);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_BIND);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_BINDING);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_CLASS);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_COLOR);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_ENGINE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_FG);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_FONT);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_FONTSET);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_FONT_NAME);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_GTK);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_HIGHEST);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_IM_MODULE_FILE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_IM_MODULE_PATH);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_INCLUDE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_INSENSITIVE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_INVALID);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_LAST);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_LOWEST);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_LTR);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_MODULE_PATH);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_NORMAL);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_PIXMAP_PATH);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_PRELIGHT);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_RC);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_RTL);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_SELECTED);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_STOCK);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_STYLE);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_TEXT);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_THEME);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_UNBIND);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_WIDGET);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_WIDGET_CLASS);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_XTHICKNESS);
    PRINT_CONSTANT((gint) GTK_RC_TOKEN_YTHICKNESS);
    PRINT_CONSTANT((gint) GTK_RECENT_CHOOSER_ERROR_INVALID_URI);
    PRINT_CONSTANT((gint) GTK_RECENT_CHOOSER_ERROR_NOT_FOUND);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_AGE);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_APPLICATION);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_DISPLAY_NAME);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_GROUP);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_MIME_TYPE);
    PRINT_CONSTANT((guint) GTK_RECENT_FILTER_URI);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_INVALID_ENCODING);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_INVALID_URI);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_NOT_FOUND);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_NOT_REGISTERED);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_READ);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_UNKNOWN);
    PRINT_CONSTANT((gint) GTK_RECENT_MANAGER_ERROR_WRITE);
    PRINT_CONSTANT((gint) GTK_RECENT_SORT_CUSTOM);
    PRINT_CONSTANT((gint) GTK_RECENT_SORT_LRU);
    PRINT_CONSTANT((gint) GTK_RECENT_SORT_MRU);
    PRINT_CONSTANT((gint) GTK_RECENT_SORT_NONE);
    PRINT_CONSTANT((guint) GTK_REGION_EVEN);
    PRINT_CONSTANT((guint) GTK_REGION_FIRST);
    PRINT_CONSTANT((guint) GTK_REGION_LAST);
    PRINT_CONSTANT((guint) GTK_REGION_ODD);
    PRINT_CONSTANT((guint) GTK_REGION_ONLY);
    PRINT_CONSTANT((guint) GTK_REGION_SORTED);
    PRINT_CONSTANT((gint) GTK_RELIEF_HALF);
    PRINT_CONSTANT((gint) GTK_RELIEF_NONE);
    PRINT_CONSTANT((gint) GTK_RELIEF_NORMAL);
    PRINT_CONSTANT((gint) GTK_RESIZE_IMMEDIATE);
    PRINT_CONSTANT((gint) GTK_RESIZE_PARENT);
    PRINT_CONSTANT((gint) GTK_RESIZE_QUEUE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_ACCEPT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_APPLY);
    PRINT_CONSTANT((gint) GTK_RESPONSE_CANCEL);
    PRINT_CONSTANT((gint) GTK_RESPONSE_CLOSE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_DELETE_EVENT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_HELP);
    PRINT_CONSTANT((gint) GTK_RESPONSE_NO);
    PRINT_CONSTANT((gint) GTK_RESPONSE_NONE);
    PRINT_CONSTANT((gint) GTK_RESPONSE_OK);
    PRINT_CONSTANT((gint) GTK_RESPONSE_REJECT);
    PRINT_CONSTANT((gint) GTK_RESPONSE_YES);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_NONE);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_LEFT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT);
    PRINT_CONSTANT((gint) GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP);
    PRINT_CONSTANT((gint) GTK_SCROLL_END);
    PRINT_CONSTANT((gint) GTK_SCROLL_ENDS);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_ENDS);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_PAGES);
    PRINT_CONSTANT((gint) GTK_SCROLL_HORIZONTAL_STEPS);
    PRINT_CONSTANT((gint) GTK_SCROLL_JUMP);
    PRINT_CONSTANT((gint) GTK_SCROLL_MINIMUM);
    PRINT_CONSTANT((gint) GTK_SCROLL_NATURAL);
    PRINT_CONSTANT((gint) GTK_SCROLL_NONE);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGES);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_DOWN);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_FORWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_LEFT);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_RIGHT);
    PRINT_CONSTANT((gint) GTK_SCROLL_PAGE_UP);
    PRINT_CONSTANT((gint) GTK_SCROLL_START);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEPS);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_DOWN);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_FORWARD);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_LEFT);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_RIGHT);
    PRINT_CONSTANT((gint) GTK_SCROLL_STEP_UP);
    PRINT_CONSTANT((gint) GTK_SELECTION_BROWSE);
    PRINT_CONSTANT((gint) GTK_SELECTION_MULTIPLE);
    PRINT_CONSTANT((gint) GTK_SELECTION_NONE);
    PRINT_CONSTANT((gint) GTK_SELECTION_SINGLE);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_AUTO);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_OFF);
    PRINT_CONSTANT((gint) GTK_SENSITIVITY_ON);
    PRINT_CONSTANT((gint) GTK_SHADOW_ETCHED_IN);
    PRINT_CONSTANT((gint) GTK_SHADOW_ETCHED_OUT);
    PRINT_CONSTANT((gint) GTK_SHADOW_IN);
    PRINT_CONSTANT((gint) GTK_SHADOW_NONE);
    PRINT_CONSTANT((gint) GTK_SHADOW_OUT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_ACCELERATOR);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_PINCH);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_ROTATE_CLOCKWISE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_ROTATE_COUNTERCLOCKWISE);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_STRETCH);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_LEFT);
    PRINT_CONSTANT((gint) GTK_SHORTCUT_GESTURE_TWO_FINGER_SWIPE_RIGHT);
    PRINT_CONSTANT((guint) GTK_SHRINK);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_BOTH);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_NONE);
    PRINT_CONSTANT((gint) GTK_SIZE_GROUP_VERTICAL);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_CONSTANT_SIZE);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH);
    PRINT_CONSTANT((gint) GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT);
    PRINT_CONSTANT((gint) GTK_SORT_ASCENDING);
    PRINT_CONSTANT((gint) GTK_SORT_DESCENDING);
    PRINT_CONSTANT((gint) GTK_SPIN_END);
    PRINT_CONSTANT((gint) GTK_SPIN_HOME);
    PRINT_CONSTANT((gint) GTK_SPIN_PAGE_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_PAGE_FORWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_STEP_BACKWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_STEP_FORWARD);
    PRINT_CONSTANT((gint) GTK_SPIN_USER_DEFINED);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_CROSSFADE);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_NONE);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_DOWN_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_LEFT_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_RIGHT_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_OVER_UP_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_UP);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_SLIDE_UP_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_DOWN);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_LEFT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_RIGHT);
    PRINT_CONSTANT((gint) GTK_STACK_TRANSITION_TYPE_UNDER_UP);
    PRINT_CONSTANT((gint) GTK_STATE_ACTIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_ACTIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_BACKDROP);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_CHECKED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DIR_LTR);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DIR_RTL);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_DROP_ACTIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_FOCUSED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_INCONSISTENT);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_INSENSITIVE);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_LINK);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_NORMAL);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_PRELIGHT);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_SELECTED);
    PRINT_CONSTANT((guint) GTK_STATE_FLAG_VISITED);
    PRINT_CONSTANT((gint) GTK_STATE_FOCUSED);
    PRINT_CONSTANT((gint) GTK_STATE_INCONSISTENT);
    PRINT_CONSTANT((gint) GTK_STATE_INSENSITIVE);
    PRINT_CONSTANT((gint) GTK_STATE_NORMAL);
    PRINT_CONSTANT((gint) GTK_STATE_PRELIGHT);
    PRINT_CONSTANT((gint) GTK_STATE_SELECTED);
    PRINT_CONSTANT(GTK_STOCK_ABOUT);
    PRINT_CONSTANT(GTK_STOCK_ADD);
    PRINT_CONSTANT(GTK_STOCK_APPLY);
    PRINT_CONSTANT(GTK_STOCK_BOLD);
    PRINT_CONSTANT(GTK_STOCK_CANCEL);
    PRINT_CONSTANT(GTK_STOCK_CAPS_LOCK_WARNING);
    PRINT_CONSTANT(GTK_STOCK_CDROM);
    PRINT_CONSTANT(GTK_STOCK_CLEAR);
    PRINT_CONSTANT(GTK_STOCK_CLOSE);
    PRINT_CONSTANT(GTK_STOCK_COLOR_PICKER);
    PRINT_CONSTANT(GTK_STOCK_CONNECT);
    PRINT_CONSTANT(GTK_STOCK_CONVERT);
    PRINT_CONSTANT(GTK_STOCK_COPY);
    PRINT_CONSTANT(GTK_STOCK_CUT);
    PRINT_CONSTANT(GTK_STOCK_DELETE);
    PRINT_CONSTANT(GTK_STOCK_DIALOG_AUTHENTICATION);
    PRINT_CONSTANT(GTK_STOCK_DIALOG_ERROR);
    PRINT_CONSTANT(GTK_STOCK_DIALOG_INFO);
    PRINT_CONSTANT(GTK_STOCK_DIALOG_QUESTION);
    PRINT_CONSTANT(GTK_STOCK_DIALOG_WARNING);
    PRINT_CONSTANT(GTK_STOCK_DIRECTORY);
    PRINT_CONSTANT(GTK_STOCK_DISCARD);
    PRINT_CONSTANT(GTK_STOCK_DISCONNECT);
    PRINT_CONSTANT(GTK_STOCK_DND);
    PRINT_CONSTANT(GTK_STOCK_DND_MULTIPLE);
    PRINT_CONSTANT(GTK_STOCK_EDIT);
    PRINT_CONSTANT(GTK_STOCK_EXECUTE);
    PRINT_CONSTANT(GTK_STOCK_FILE);
    PRINT_CONSTANT(GTK_STOCK_FIND);
    PRINT_CONSTANT(GTK_STOCK_FIND_AND_REPLACE);
    PRINT_CONSTANT(GTK_STOCK_FLOPPY);
    PRINT_CONSTANT(GTK_STOCK_FULLSCREEN);
    PRINT_CONSTANT(GTK_STOCK_GOTO_BOTTOM);
    PRINT_CONSTANT(GTK_STOCK_GOTO_FIRST);
    PRINT_CONSTANT(GTK_STOCK_GOTO_LAST);
    PRINT_CONSTANT(GTK_STOCK_GOTO_TOP);
    PRINT_CONSTANT(GTK_STOCK_GO_BACK);
    PRINT_CONSTANT(GTK_STOCK_GO_DOWN);
    PRINT_CONSTANT(GTK_STOCK_GO_FORWARD);
    PRINT_CONSTANT(GTK_STOCK_GO_UP);
    PRINT_CONSTANT(GTK_STOCK_HARDDISK);
    PRINT_CONSTANT(GTK_STOCK_HELP);
    PRINT_CONSTANT(GTK_STOCK_HOME);
    PRINT_CONSTANT(GTK_STOCK_INDENT);
    PRINT_CONSTANT(GTK_STOCK_INDEX);
    PRINT_CONSTANT(GTK_STOCK_INFO);
    PRINT_CONSTANT(GTK_STOCK_ITALIC);
    PRINT_CONSTANT(GTK_STOCK_JUMP_TO);
    PRINT_CONSTANT(GTK_STOCK_JUSTIFY_CENTER);
    PRINT_CONSTANT(GTK_STOCK_JUSTIFY_FILL);
    PRINT_CONSTANT(GTK_STOCK_JUSTIFY_LEFT);
    PRINT_CONSTANT(GTK_STOCK_JUSTIFY_RIGHT);
    PRINT_CONSTANT(GTK_STOCK_LEAVE_FULLSCREEN);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_FORWARD);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_NEXT);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_PAUSE);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_PLAY);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_PREVIOUS);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_RECORD);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_REWIND);
    PRINT_CONSTANT(GTK_STOCK_MEDIA_STOP);
    PRINT_CONSTANT(GTK_STOCK_MISSING_IMAGE);
    PRINT_CONSTANT(GTK_STOCK_NETWORK);
    PRINT_CONSTANT(GTK_STOCK_NEW);
    PRINT_CONSTANT(GTK_STOCK_NO);
    PRINT_CONSTANT(GTK_STOCK_OK);
    PRINT_CONSTANT(GTK_STOCK_OPEN);
    PRINT_CONSTANT(GTK_STOCK_ORIENTATION_LANDSCAPE);
    PRINT_CONSTANT(GTK_STOCK_ORIENTATION_PORTRAIT);
    PRINT_CONSTANT(GTK_STOCK_ORIENTATION_REVERSE_LANDSCAPE);
    PRINT_CONSTANT(GTK_STOCK_ORIENTATION_REVERSE_PORTRAIT);
    PRINT_CONSTANT(GTK_STOCK_PAGE_SETUP);
    PRINT_CONSTANT(GTK_STOCK_PASTE);
    PRINT_CONSTANT(GTK_STOCK_PREFERENCES);
    PRINT_CONSTANT(GTK_STOCK_PRINT);
    PRINT_CONSTANT(GTK_STOCK_PRINT_ERROR);
    PRINT_CONSTANT(GTK_STOCK_PRINT_PAUSED);
    PRINT_CONSTANT(GTK_STOCK_PRINT_PREVIEW);
    PRINT_CONSTANT(GTK_STOCK_PRINT_REPORT);
    PRINT_CONSTANT(GTK_STOCK_PRINT_WARNING);
    PRINT_CONSTANT(GTK_STOCK_PROPERTIES);
    PRINT_CONSTANT(GTK_STOCK_QUIT);
    PRINT_CONSTANT(GTK_STOCK_REDO);
    PRINT_CONSTANT(GTK_STOCK_REFRESH);
    PRINT_CONSTANT(GTK_STOCK_REMOVE);
    PRINT_CONSTANT(GTK_STOCK_REVERT_TO_SAVED);
    PRINT_CONSTANT(GTK_STOCK_SAVE);
    PRINT_CONSTANT(GTK_STOCK_SAVE_AS);
    PRINT_CONSTANT(GTK_STOCK_SELECT_ALL);
    PRINT_CONSTANT(GTK_STOCK_SELECT_COLOR);
    PRINT_CONSTANT(GTK_STOCK_SELECT_FONT);
    PRINT_CONSTANT(GTK_STOCK_SORT_ASCENDING);
    PRINT_CONSTANT(GTK_STOCK_SORT_DESCENDING);
    PRINT_CONSTANT(GTK_STOCK_SPELL_CHECK);
    PRINT_CONSTANT(GTK_STOCK_STOP);
    PRINT_CONSTANT(GTK_STOCK_STRIKETHROUGH);
    PRINT_CONSTANT(GTK_STOCK_UNDELETE);
    PRINT_CONSTANT(GTK_STOCK_UNDERLINE);
    PRINT_CONSTANT(GTK_STOCK_UNDO);
    PRINT_CONSTANT(GTK_STOCK_UNINDENT);
    PRINT_CONSTANT(GTK_STOCK_YES);
    PRINT_CONSTANT(GTK_STOCK_ZOOM_100);
    PRINT_CONSTANT(GTK_STOCK_ZOOM_FIT);
    PRINT_CONSTANT(GTK_STOCK_ZOOM_IN);
    PRINT_CONSTANT(GTK_STOCK_ZOOM_OUT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_ACCELERATOR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_ARROW);
    PRINT_CONSTANT(GTK_STYLE_CLASS_BACKGROUND);
    PRINT_CONSTANT(GTK_STYLE_CLASS_BOTTOM);
    PRINT_CONSTANT(GTK_STYLE_CLASS_BUTTON);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CALENDAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CELL);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CHECK);
    PRINT_CONSTANT(GTK_STYLE_CLASS_COMBOBOX_ENTRY);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CONTEXT_MENU);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CSD);
    PRINT_CONSTANT(GTK_STYLE_CLASS_CURSOR_HANDLE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_DEFAULT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_DESTRUCTIVE_ACTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_DIM_LABEL);
    PRINT_CONSTANT(GTK_STYLE_CLASS_DND);
    PRINT_CONSTANT(GTK_STYLE_CLASS_DOCK);
    PRINT_CONSTANT(GTK_STYLE_CLASS_ENTRY);
    PRINT_CONSTANT(GTK_STYLE_CLASS_ERROR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_EXPANDER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_FLAT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_FRAME);
    PRINT_CONSTANT(GTK_STYLE_CLASS_GRIP);
    PRINT_CONSTANT(GTK_STYLE_CLASS_HEADER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_HIGHLIGHT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_HORIZONTAL);
    PRINT_CONSTANT(GTK_STYLE_CLASS_IMAGE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_INFO);
    PRINT_CONSTANT(GTK_STYLE_CLASS_INLINE_TOOLBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_INSERTION_CURSOR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LABEL);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LEFT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LEVEL_BAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LINKED);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LIST);
    PRINT_CONSTANT(GTK_STYLE_CLASS_LIST_ROW);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MARK);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MENU);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MENUBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MENUITEM);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MESSAGE_DIALOG);
    PRINT_CONSTANT(GTK_STYLE_CLASS_MONOSPACE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_NEEDS_ATTENTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_NOTEBOOK);
    PRINT_CONSTANT(GTK_STYLE_CLASS_OSD);
    PRINT_CONSTANT(GTK_STYLE_CLASS_OVERSHOOT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_PANE_SEPARATOR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_PAPER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_POPOVER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_POPUP);
    PRINT_CONSTANT(GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_PROGRESSBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_PULSE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_QUESTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_RADIO);
    PRINT_CONSTANT(GTK_STYLE_CLASS_RAISED);
    PRINT_CONSTANT(GTK_STYLE_CLASS_READ_ONLY);
    PRINT_CONSTANT(GTK_STYLE_CLASS_RIGHT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_RUBBERBAND);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SCALE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SCALE_HAS_MARKS_ABOVE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SCALE_HAS_MARKS_BELOW);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SCROLLBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SCROLLBARS_JUNCTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SEPARATOR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SIDEBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SLIDER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SPINBUTTON);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SPINNER);
    PRINT_CONSTANT(GTK_STYLE_CLASS_STATUSBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SUBTITLE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_SUGGESTED_ACTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TITLE);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TITLEBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TOOLBAR);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TOOLTIP);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TOP);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TOUCH_SELECTION);
    PRINT_CONSTANT(GTK_STYLE_CLASS_TROUGH);
    PRINT_CONSTANT(GTK_STYLE_CLASS_UNDERSHOOT);
    PRINT_CONSTANT(GTK_STYLE_CLASS_VERTICAL);
    PRINT_CONSTANT(GTK_STYLE_CLASS_VIEW);
    PRINT_CONSTANT(GTK_STYLE_CLASS_WARNING);
    PRINT_CONSTANT(GTK_STYLE_CLASS_WIDE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_NONE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_RECURSE);
    PRINT_CONSTANT((guint) GTK_STYLE_CONTEXT_PRINT_SHOW_STYLE);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BACKGROUND_COLOR);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BACKGROUND_IMAGE);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BORDER_COLOR);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BORDER_RADIUS);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BORDER_STYLE);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_BORDER_WIDTH);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_COLOR);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_FONT);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_MARGIN);
    PRINT_CONSTANT(GTK_STYLE_PROPERTY_PADDING);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_FALLBACK);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_SETTINGS);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_THEME);
    PRINT_CONSTANT(GTK_STYLE_PROVIDER_PRIORITY_USER);
    PRINT_CONSTANT(GTK_STYLE_REGION_COLUMN);
    PRINT_CONSTANT(GTK_STYLE_REGION_COLUMN_HEADER);
    PRINT_CONSTANT(GTK_STYLE_REGION_ROW);
    PRINT_CONSTANT(GTK_STYLE_REGION_TAB);
    PRINT_CONSTANT((guint) GTK_TARGET_OTHER_APP);
    PRINT_CONSTANT((guint) GTK_TARGET_OTHER_WIDGET);
    PRINT_CONSTANT((guint) GTK_TARGET_SAME_APP);
    PRINT_CONSTANT((guint) GTK_TARGET_SAME_WIDGET);
    PRINT_CONSTANT((gint) GTK_TEXT_BUFFER_TARGET_INFO_BUFFER_CONTENTS);
    PRINT_CONSTANT((gint) GTK_TEXT_BUFFER_TARGET_INFO_RICH_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_BUFFER_TARGET_INFO_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_LTR);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_NONE);
    PRINT_CONSTANT((gint) GTK_TEXT_DIR_RTL);
    PRINT_CONSTANT((gint) GTK_TEXT_EXTEND_SELECTION_LINE);
    PRINT_CONSTANT((gint) GTK_TEXT_EXTEND_SELECTION_WORD);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_CASE_INSENSITIVE);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_TEXT_ONLY);
    PRINT_CONSTANT((guint) GTK_TEXT_SEARCH_VISIBLE_ONLY);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_ABOVE);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_ABOVE_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_BELOW);
    PRINT_CONSTANT((gint) GTK_TEXT_VIEW_LAYER_BELOW_TEXT);
    PRINT_CONSTANT(GTK_TEXT_VIEW_PRIORITY_VALIDATE);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_BOTTOM);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_LEFT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_PRIVATE);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_RIGHT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_TEXT);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_TOP);
    PRINT_CONSTANT((gint) GTK_TEXT_WINDOW_WIDGET);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_BOTH);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_BOTH_HORIZ);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_ICONS);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_SPACE_EMPTY);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_SPACE_LINE);
    PRINT_CONSTANT((gint) GTK_TOOLBAR_TEXT);
    PRINT_CONSTANT((guint) GTK_TOOL_PALETTE_DRAG_GROUPS);
    PRINT_CONSTANT((guint) GTK_TOOL_PALETTE_DRAG_ITEMS);
    PRINT_CONSTANT((guint) GTK_TREE_MODEL_ITERS_PERSIST);
    PRINT_CONSTANT((guint) GTK_TREE_MODEL_LIST_ONLY);
    PRINT_CONSTANT(GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID);
    PRINT_CONSTANT(GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_AUTOSIZE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_FIXED);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_COLUMN_GROW_ONLY);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_AFTER);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_BEFORE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_BOTH);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_HORIZONTAL);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_NONE);
    PRINT_CONSTANT((gint) GTK_TREE_VIEW_GRID_LINES_VERTICAL);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_ACCELERATOR);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_AUTO);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_MENU);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_MENUBAR);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_MENUITEM);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_PLACEHOLDER);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_POPUP);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_POPUP_WITH_ACCELS);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_SEPARATOR);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_TOOLBAR);
    PRINT_CONSTANT((guint) GTK_UI_MANAGER_TOOLITEM);
    PRINT_CONSTANT((gint) GTK_UNIT_INCH);
    PRINT_CONSTANT((gint) GTK_UNIT_MM);
    PRINT_CONSTANT((gint) GTK_UNIT_NONE);
    PRINT_CONSTANT((gint) GTK_UNIT_POINTS);
    PRINT_CONSTANT((gint) GTK_UPDATE_ALWAYS);
    PRINT_CONSTANT((gint) GTK_UPDATE_IF_VALID);
    PRINT_CONSTANT((gint) GTK_WIDGET_HELP_TOOLTIP);
    PRINT_CONSTANT((gint) GTK_WIDGET_HELP_WHATS_THIS);
    PRINT_CONSTANT((gint) GTK_WINDOW_POPUP);
    PRINT_CONSTANT((gint) GTK_WINDOW_TOPLEVEL);
    PRINT_CONSTANT((gint) GTK_WIN_POS_CENTER);
    PRINT_CONSTANT((gint) GTK_WIN_POS_CENTER_ALWAYS);
    PRINT_CONSTANT((gint) GTK_WIN_POS_CENTER_ON_PARENT);
    PRINT_CONSTANT((gint) GTK_WIN_POS_MOUSE);
    PRINT_CONSTANT((gint) GTK_WIN_POS_NONE);
    PRINT_CONSTANT((gint) GTK_WRAP_CHAR);
    PRINT_CONSTANT((gint) GTK_WRAP_NONE);
    PRINT_CONSTANT((gint) GTK_WRAP_WORD);
    PRINT_CONSTANT((gint) GTK_WRAP_WORD_CHAR);
    return 0;
}
